# glasz

![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/James11222/glasz/ci.yml?logo=Github&label=CI)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/James11222/glasz/cd.yml)
![Codecov](https://img.shields.io/codecov/c/github/James11222/glasz?logo=Codecov)

![PyPI - Version](https://img.shields.io/pypi/v/glasz)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/glasz)

**glasz** is a package designed to aid in joint analyses of kSZ+GGL. For more
information, please read Sunseri et al. 2025 (in prep). This code is built on
`pyccl` and was derived from the work done in
[Amodeo et al. 2021](https://arxiv.org/pdf/2009.05558).

Authors: James Sunseri

![diagram of kSZ+GGL](./images/Lensing_Diagram.png)

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

```{toctree}
:maxdepth: 2
:caption: Getting Started
:hidden:

notebooks/tutorial
notebooks/profiles
notebooks/kSZ
notebooks/GGL
notebooks/halo_model
notebooks/two-halo
```

```{toctree}
:maxdepth: 2
:caption: API
:hidden:

api/glasz
```
